"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.OsanoUi = void 0;
var _reactNativeEventListeners = require("@tecnavia/react-native-event-listeners");
var _reactNative = require("react-native");
var _osanoWebview = require("./osano-webview");
var _react = _interopRequireWildcard(require("react"));
var _osanoContext = _interopRequireDefault(require("./osano-context"));
var _osanoWebviewUtils = require("./osano-webview-utils");
var _useJavascriptInjection = require("./useJavascriptInjection");
var _useMessage = require("./useMessage");
var _events = require("./events");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/* eslint-disable react-hooks/exhaustive-deps */

const styles = _reactNative.StyleSheet.create({
  hidden: {
    display: "none"
  },
  absolute: {
    backgroundColor: "rgba(0, 0, 0, 0.8)",
    position: "absolute",
    top: 0,
    left: 0,
    right: 0,
    bottom: 0
  }
});
/**
 * Osano ui component handle if the webview is visible or not
 * Handle also events to communicate with the webview and also handle onMessage from the webview
 */
const OsanoUi = props => {
  const {
    insets,
    callbacks
  } = props;
  const ref = (0, _react.useRef)(null);
  const consent = (0, _react.useRef)(undefined);
  const [uiHidden, setUIHidden] = (0, _react.useState)(true);
  const [hidden, setHidden] = (0, _react.useState)(true);
  const updateUIHidden = (0, _react.useCallback)(() => {
    setUIHidden(false);
  }, []);
  const clearConsent = (0, _react.useCallback)(() => {
    consent.current = undefined;
  }, []);
  const getConsent = (0, _react.useCallback)(() => {
    if (consent.current) {
      var _callbacks$onConsent;
      callbacks === null || callbacks === void 0 || (_callbacks$onConsent = callbacks.onConsent) === null || _callbacks$onConsent === void 0 || _callbacks$onConsent.call(callbacks, consent.current);
    }
  }, [callbacks]);
  (0, _react.useEffect)(() => {
    const onShowUI = _reactNativeEventListeners.EventRegister.on(_events.Events.SHOW_UI, updateUIHidden);
    const onContentClear = _reactNativeEventListeners.EventRegister.on(_events.Events.CLEAR_CONSENT, clearConsent);
    const onAskContent = _reactNativeEventListeners.EventRegister.on(_events.Events.ASK_CONSENT, getConsent);
    return () => {
      _reactNativeEventListeners.EventRegister.rm(onShowUI);
      _reactNativeEventListeners.EventRegister.rm(onContentClear);
      _reactNativeEventListeners.EventRegister.rm(onAskContent);
    };
  }, []);
  (0, _react.useEffect)(() => {
    if (hidden) {
      var _callbacks$onClose;
      callbacks === null || callbacks === void 0 || (_callbacks$onClose = callbacks.onClose) === null || _callbacks$onClose === void 0 || _callbacks$onClose.call(callbacks);
    }
  }, [hidden, callbacks]);
  const onUiChanged = (0, _react.useCallback)((component, state) => {
    var _callbacks$onUiChange;
    setHidden(state === "hide");
    callbacks === null || callbacks === void 0 || (_callbacks$onUiChange = callbacks.onUiChanged) === null || _callbacks$onUiChange === void 0 || _callbacks$onUiChange.call(callbacks, component, state);
  }, [callbacks]);
  const onConsent = (0, _react.useCallback)(newConsent => {
    var _callbacks$onConsent2;
    consent.current = newConsent;
    callbacks === null || callbacks === void 0 || (_callbacks$onConsent2 = callbacks.onConsent) === null || _callbacks$onConsent2 === void 0 || _callbacks$onConsent2.call(callbacks, newConsent);
  }, [callbacks]);
  const onMessage = (0, _useMessage.useMessage)({
    ...callbacks,
    onUiChanged,
    onConsent
  });
  (0, _useJavascriptInjection.useJavascriptInjection)(ref);

  /**
   * Handle the url otu of the webview, open other links in the browser
   */
  const onShouldStartLoadWithRequest = (0, _react.useCallback)(event => {
    if (!(callbacks !== null && callbacks !== void 0 && callbacks.onLoadUrl)) return true;
    //TODO: Reject active callback????
    return callbacks.onLoadUrl(event);
  }, [callbacks]);
  const hide = (0, _react.useCallback)(() => setHidden(true), [setHidden]);
  const {
    top,
    bottom
  } = insets;
  return /*#__PURE__*/_react.default.createElement(_osanoContext.default.Consumer, null, configuration => {
    if (!configuration) return null;
    const {
      baseActionUrl,
      siteDomain: baseUrl
    } = configuration;
    let source;
    if (baseActionUrl) {
      source = {
        uri: baseActionUrl
      };
    } else {
      source = {
        html: _osanoWebviewUtils.OsanoWebViewUtils.html(configuration),
        baseUrl
      };
    }
    return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
      style: uiHidden || hidden ? styles.hidden : [styles.absolute, {
        top,
        bottom
      }]
    }, /*#__PURE__*/_react.default.createElement(_osanoWebview.OsanoWebView, {
      key: `${JSON.stringify(configuration)}`,
      ref: ref,
      source: source,
      onMessage: onMessage,
      onError: hide,
      onHttpError: hide,
      onShouldStartLoadWithRequest: onShouldStartLoadWithRequest
    }));
  });
};
exports.OsanoUi = OsanoUi;
//# sourceMappingURL=osano-ui.js.map