"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.OsanoHook = exports.Osano = void 0;
var _reactNativeEventListeners = require("@tecnavia/react-native-event-listeners");
var _events = require("./events");
var _osanoPromises = require("./osano-promises");
var _reactNativeTecnaviaUtils = require("react-native-tecnavia-utils");
let hook;
let configurationToConsume;
let OsanoHook = exports.OsanoHook = void 0;
(function (_OsanoHook) {
  const consumeConfiguration = _OsanoHook.consumeConfiguration = () => {
    var _hook;
    if (!configurationToConsume) return;
    (_hook = hook) === null || _hook === void 0 || _hook(configurationToConsume);
    configurationToConsume = undefined;
  };
  const setHook = _OsanoHook.setHook = cb => {
    hook = cb;
    consumeConfiguration();
  };
})(OsanoHook || (exports.OsanoHook = OsanoHook = {}));
/**
 * This interface is used to interact with the Osano component
 * You should add only methods that you want to expose outside of the library
 */
let Osano = exports.Osano = void 0;
(function (_Osano) {
  /**
   * This method is used to update the configuration of the Osano component
   * Could trigger a re-render of the component, Osano could appear
   * With this params to see the consent use Container callbacks
   */
  const update = value => {
    var _hook2;
    if (!hook) {
      configurationToConsume = value;
      return;
    }
    configurationToConsume = undefined;
    (_hook2 = hook) === null || _hook2 === void 0 || _hook2(value);
  };

  /**
   * This method save the promise and trigger the event, see osano-ui.tsx
   * The promise will be resolved when the webview will send the data to the app
   */
  const askTcData = _Osano.askTcData = async () => {
    try {
      const result = await _osanoPromises.OsanoPromises.make("tcData", true, () => {
        _reactNativeEventListeners.EventRegister.emit(_events.Events.ASK_TC_DATA);
      });
      let vendorList;
      try {
        vendorList = await askVendorListData();
      } catch (e) {
        _reactNativeTecnaviaUtils.Logger.error(`Error asking vendor list: ${e.message}`);
      }
      await _reactNativeTecnaviaUtils.CmpStorage.setTCData(result, vendorList);
      return result;
    } catch (e) {
      _reactNativeTecnaviaUtils.Logger.error(`Error asking tc data: ${e.message}`);
      throw e;
    }
  };
  const askUspData = _Osano.askUspData = async () => {
    try {
      const result = await _osanoPromises.OsanoPromises.make("uspData", true, () => {
        _reactNativeEventListeners.EventRegister.emit(_events.Events.ASK_USP_DATA);
      });
      await _reactNativeTecnaviaUtils.CmpStorage.setUSPData(result);
      return result;
    } catch (e) {
      _reactNativeTecnaviaUtils.Logger.error(`Error asking usp data: ${e.message}`);
      throw e;
    }
  };
  const askConsentData = _Osano.askConsentData = () => {
    return _osanoPromises.OsanoPromises.make("consentData", true, () => {
      _reactNativeEventListeners.EventRegister.emit(_events.Events.ASK_CONSENT_DATA);
    });
  };
  const askVendorListData = _Osano.askVendorListData = () => {
    return _osanoPromises.OsanoPromises.make("vendorListData", true, () => {
      _reactNativeEventListeners.EventRegister.emit(_events.Events.ASK_VENDOR_LIST_DATA);
    });
  };
  const init = _Osano.init = configuration => {
    //if the webview URL is remote configurationId and projectsId are read server side
    if (!configuration.baseActionUrl) {
      if (!configuration.customerId) throw new Error("Missing customerId, can't retrieve script");
      if (!configuration.projectId) throw new Error("Missing projectId, can't retrieve script");
      if (!configuration.siteDomain) throw new Error("Missing siteDomain, can't store cookies without it");
    }
    return _osanoPromises.OsanoPromises.make("init", false, () => {
      update(configuration);
    });
  };
  const ask = _Osano.ask = () => {
    return _osanoPromises.OsanoPromises.make("askConsent", false, () => {
      _reactNativeEventListeners.EventRegister.emit(_events.Events.SHOW_UI);
      _reactNativeEventListeners.EventRegister.emit(_events.Events.ASK_CONSENT);
    });
  };
  const resetIfNecessary = _Osano.resetIfNecessary = async configuration => {
    try {
      const timestamp = await getConsentDate();
      if (configuration.resetConsentDate && timestamp) {
        //clear local data if necessary
        const consentDate = _reactNativeTecnaviaUtils.DateUtils.getDateString(timestamp, "YYYYMMDD");
        if (consentDate < configuration.resetConsentDate) {
          await clear();
          showDialog();
        }
      }
    } catch (e) {
      _reactNativeTecnaviaUtils.Logger.error(`Error resetting if necessary: ${e.message}`);
    }
  };
  const destroy = _Osano.destroy = () => {
    var _hook3;
    (_hook3 = hook) === null || _hook3 === void 0 || _hook3(undefined);
  };
  const change = _Osano.change = () => {
    return _osanoPromises.OsanoPromises.make("changeConsent", false, () => {
      _reactNativeEventListeners.EventRegister.emit(_events.Events.SHOW_UI);
      _reactNativeEventListeners.EventRegister.emit(_events.Events.CHANGE_CONSENT);
    });
  };
  const showDrawer = _Osano.showDrawer = () => {
    _reactNativeEventListeners.EventRegister.emit(_events.Events.SHOW_UI);
    _reactNativeEventListeners.EventRegister.emit(_events.Events.SHOW_DRAWER);
  };
  const showDialog = _Osano.showDialog = () => {
    _reactNativeEventListeners.EventRegister.emit(_events.Events.SHOW_UI);
    _reactNativeEventListeners.EventRegister.emit(_events.Events.SHOW_DIALOG);
  };
  const clear = _Osano.clear = () => {
    _reactNativeEventListeners.EventRegister.emit(_events.Events.CLEAR_CONSENT);
    return _reactNativeTecnaviaUtils.CmpStorage.clearAll();
  };
  const getConsentDate = _Osano.getConsentDate = () => {
    return _osanoPromises.OsanoPromises.make("getConsentDate", true, () => {
      _reactNativeEventListeners.EventRegister.emit(_events.Events.GET_CONSENT_DATE);
    });
  };
})(Osano || (exports.Osano = Osano = {}));
//# sourceMappingURL=osano.js.map