"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useCallbacks = void 0;
var _react = require("react");
var _osanoPromises = require("./osano-promises");
const useCallbacks = props => {
  const {
    onInitialized: defaultOnInitialized,
    onClose: defaultOnClose,
    onConsent: defaultOnConsent,
    onError: defaultOnError,
    onLoadUrl: defaultOnLoadUrl,
    onUspData: defaultOnUspData,
    onTcData: defaultOnTcData,
    onConsentDate: defaultOnConsentDate,
    onConsentData: defaultOnConsentData,
    onVendorList: defaultOnVendorList
  } = props;
  const lastConsent = (0, _react.useRef)();
  const onInitialized = (0, _react.useCallback)(() => {
    _osanoPromises.OsanoPromises.resolve("init");
    defaultOnInitialized === null || defaultOnInitialized === void 0 || defaultOnInitialized();
  }, [defaultOnInitialized]);
  const onConsent = (0, _react.useCallback)(consent => {
    lastConsent.current = consent;
    _osanoPromises.OsanoPromises.resolve("askConsent", consent);
    defaultOnConsent === null || defaultOnConsent === void 0 || defaultOnConsent(consent);
  }, [defaultOnConsent]);
  const onTcData = (0, _react.useCallback)(data => {
    _osanoPromises.OsanoPromises.resolve("tcData", data);
    defaultOnTcData === null || defaultOnTcData === void 0 || defaultOnTcData(data);
  }, [defaultOnTcData]);
  const onUspData = (0, _react.useCallback)(data => {
    _osanoPromises.OsanoPromises.resolve("uspData", data);
    defaultOnUspData === null || defaultOnUspData === void 0 || defaultOnUspData(data);
  }, [defaultOnUspData]);
  const onConsentDate = (0, _react.useCallback)(data => {
    _osanoPromises.OsanoPromises.resolve("getConsentDate", data);
    defaultOnConsentDate === null || defaultOnConsentDate === void 0 || defaultOnConsentDate(data);
  }, [defaultOnConsentDate]);
  const onConsentData = (0, _react.useCallback)(data => {
    _osanoPromises.OsanoPromises.resolve("consentData", data);
    defaultOnConsentData === null || defaultOnConsentData === void 0 || defaultOnConsentData(data);
  }, [defaultOnConsentData]);
  const onVendorList = (0, _react.useCallback)(data => {
    _osanoPromises.OsanoPromises.resolve("vendorListData", data);
    defaultOnVendorList === null || defaultOnVendorList === void 0 || defaultOnVendorList(data);
  }, [defaultOnVendorList]);
  const onClose = (0, _react.useCallback)(() => {
    _osanoPromises.OsanoPromises.resolve("changeConsent", lastConsent.current);
    defaultOnClose === null || defaultOnClose === void 0 || defaultOnClose();
  }, [defaultOnClose]);
  const onError = (0, _react.useCallback)(error => {
    _osanoPromises.OsanoPromises.rejects(error);
    defaultOnError === null || defaultOnError === void 0 || defaultOnError(error);
  }, [defaultOnError]);
  const onCookieBlocked = (0, _react.useCallback)(cookie => onError === null || onError === void 0 ? void 0 : onError(new Error(`Cookie blocked: ${cookie}`)), [onError]);
  const onScriptBlocked = (0, _react.useCallback)(src => onError === null || onError === void 0 ? void 0 : onError(new Error(`Script blocked: ${src}`)), [onError]);
  const onIframeBlocked = (0, _react.useCallback)(src => onError === null || onError === void 0 ? void 0 : onError(new Error(`Iframe blocked: ${src}`)), [onError]);
  return {
    onInitialized,
    onClose,
    onConsent,
    onLoadUrl: defaultOnLoadUrl,
    onUspData,
    onTcData,
    onConsentDate,
    onError,
    onCookieBlocked,
    onScriptBlocked,
    onIframeBlocked,
    onConsentData,
    onVendorList
  };
};
exports.useCallbacks = useCallbacks;
//# sourceMappingURL=useCallbacks.js.map