/* eslint-disable react-hooks/exhaustive-deps */
import { EventRegister } from "@tecnavia/react-native-event-listeners";
import { StyleSheet, View } from "react-native";
import { OsanoWebView } from "./osano-webview";
import React, { useCallback, useEffect, useRef, useState } from "react";
import OsanoContext from "./osano-context";
import { OsanoWebViewUtils } from "./osano-webview-utils";
import { useJavascriptInjection } from "./useJavascriptInjection";
import { useMessage } from "./useMessage";
import { Events } from "./events";
const styles = StyleSheet.create({
  hidden: {
    display: "none"
  },
  absolute: {
    backgroundColor: "rgba(0, 0, 0, 0.8)",
    position: "absolute",
    top: 0,
    left: 0,
    right: 0,
    bottom: 0
  }
});
/**
 * Osano ui component handle if the webview is visible or not
 * Handle also events to communicate with the webview and also handle onMessage from the webview
 */
export const OsanoUi = props => {
  const {
    insets,
    callbacks
  } = props;
  const ref = useRef(null);
  const consent = useRef(undefined);
  const [uiHidden, setUIHidden] = useState(true);
  const [hidden, setHidden] = useState(true);
  const updateUIHidden = useCallback(() => {
    setUIHidden(false);
  }, []);
  const clearConsent = useCallback(() => {
    consent.current = undefined;
  }, []);
  const getConsent = useCallback(() => {
    if (consent.current) {
      var _callbacks$onConsent;
      callbacks === null || callbacks === void 0 || (_callbacks$onConsent = callbacks.onConsent) === null || _callbacks$onConsent === void 0 || _callbacks$onConsent.call(callbacks, consent.current);
    }
  }, [callbacks]);
  useEffect(() => {
    const onShowUI = EventRegister.on(Events.SHOW_UI, updateUIHidden);
    const onContentClear = EventRegister.on(Events.CLEAR_CONSENT, clearConsent);
    const onAskContent = EventRegister.on(Events.ASK_CONSENT, getConsent);
    return () => {
      EventRegister.rm(onShowUI);
      EventRegister.rm(onContentClear);
      EventRegister.rm(onAskContent);
    };
  }, []);
  useEffect(() => {
    if (hidden) {
      var _callbacks$onClose;
      callbacks === null || callbacks === void 0 || (_callbacks$onClose = callbacks.onClose) === null || _callbacks$onClose === void 0 || _callbacks$onClose.call(callbacks);
    }
  }, [hidden, callbacks]);
  const onUiChanged = useCallback((component, state) => {
    var _callbacks$onUiChange;
    setHidden(state === "hide");
    callbacks === null || callbacks === void 0 || (_callbacks$onUiChange = callbacks.onUiChanged) === null || _callbacks$onUiChange === void 0 || _callbacks$onUiChange.call(callbacks, component, state);
  }, [callbacks]);
  const onConsent = useCallback(newConsent => {
    var _callbacks$onConsent2;
    consent.current = newConsent;
    callbacks === null || callbacks === void 0 || (_callbacks$onConsent2 = callbacks.onConsent) === null || _callbacks$onConsent2 === void 0 || _callbacks$onConsent2.call(callbacks, newConsent);
  }, [callbacks]);
  const onMessage = useMessage({
    ...callbacks,
    onUiChanged,
    onConsent
  });
  useJavascriptInjection(ref);

  /**
   * Handle the url otu of the webview, open other links in the browser
   */
  const onShouldStartLoadWithRequest = useCallback(event => {
    if (!(callbacks !== null && callbacks !== void 0 && callbacks.onLoadUrl)) return true;
    //TODO: Reject active callback????
    return callbacks.onLoadUrl(event);
  }, [callbacks]);
  const hide = useCallback(() => setHidden(true), [setHidden]);
  const {
    top,
    bottom
  } = insets;
  return /*#__PURE__*/React.createElement(OsanoContext.Consumer, null, configuration => {
    if (!configuration) return null;
    const {
      baseActionUrl,
      siteDomain: baseUrl
    } = configuration;
    let source;
    if (baseActionUrl) {
      source = {
        uri: baseActionUrl
      };
    } else {
      source = {
        html: OsanoWebViewUtils.html(configuration),
        baseUrl
      };
    }
    return /*#__PURE__*/React.createElement(View, {
      style: uiHidden || hidden ? styles.hidden : [styles.absolute, {
        top,
        bottom
      }]
    }, /*#__PURE__*/React.createElement(OsanoWebView, {
      key: `${JSON.stringify(configuration)}`,
      ref: ref,
      source: source,
      onMessage: onMessage,
      onError: hide,
      onHttpError: hide,
      onShouldStartLoadWithRequest: onShouldStartLoadWithRequest
    }));
  });
};
//# sourceMappingURL=osano-ui.js.map